@@ -3,7 +3,7 @@ package Auth::Kokolores::Plugin;
 use Moose;
 
 # ABSTRACT: base class for kokolores plugins
-our $VERSION = '1.00'; # VERSION
+our $VERSION = '1.01'; # VERSION
 
 has 'name' => ( is => 'ro', isa => 'Str', required => 1 );
 
@@ -26,9 +26,19 @@ sub child_init {
   return;
 }
 
+sub pre_process {
+  my ( $self, $r ) = @_;
+  return;
+}
+
 sub authenticate {
-  my ( $self ) = @_;
-  return 0;
+  my ( $self, $r ) = @_;
+  return;
+}
+
+sub post_process {
+  my ( $self, $r, $response ) = @_;
+  return;
 }
 
 sub shutdown {
@@ -50,7 +60,7 @@ Auth::Kokolores::Plugin - base class for kokolores plugins
 
 =head1 VERSION
 
-version 1.00
+version 1.01
 
 =head1 AUTHOR
 
